@@ -542,7 +542,7 @@ class Insight_Definition:
         body = df.to_json(orient="table", index=index)
         if(qc_id!=None):
             body["qcId"] = qc_id
-            
+
         url = self.smart_insight_url+"/definitions/"+self.definition_id+"/data_queries/"+data_id+"/data"
         #logging.info("URL: {}".format(url))
         s = requests.Session()
@@ -1136,7 +1136,7 @@ class Insight_Definition:
         if(r.json()!=[]):
             body = {
                 "role": "ADMIN",
-                "userId": r.json()["id"]
+                "userId": r.json()[0]["id"]
             }
 
             url = self.smart_insight_url+"/insights/8a09ec79-8e1e-401a-bdec-70d33c9c1543/users"
@@ -1177,7 +1177,7 @@ class Insight_Definition:
         if(r.json()!=[]):
             body = {
                 "role": "FOLLOWER",
-                "userId": r.json()["id"]
+                "userId": r.json()[0]["id"]
             }
 
             url = self.smart_insight_url+"/insights/8a09ec79-8e1e-401a-bdec-70d33c9c1543/users"
